import { useEffect } from "react";
import {
  useTagsAndCommitIds,
  useIocStatus,
  useIOC
} from "../../../api/SwaggerApi";

function onError(message) {
  console.warn(message);
}

export function IOCDetailFetcher({ ioc, index, setIocs }) {
  const [tagOrCommitId, getTagOrCommitId] = useTagsAndCommitIds(onError);
  const [iocStatus, getIocStatus] = useIocStatus();
  const [iocDetails, getIocDetails] = useIOC(ioc.id);

  useEffect(() => {
    if (ioc.sourceVersion) {
      getTagOrCommitId(ioc.gitProjectId, ioc.sourceVersion);
    }

    getIocStatus(ioc.id);
    getIocDetails(ioc.id);
  }, [ioc, getTagOrCommitId, getIocStatus, getIocDetails]);

  useEffect(() => {
    setIocs((iocs) => {
      iocs[index].sourceVersionShort =
        tagOrCommitId?.length === 1
          ? tagOrCommitId[0].shortReference
          : iocs[index].sourceVersionShort;
      iocs[index].host = iocs[index].activeDeployment?.host;
      iocs[index].alertSeverity = iocStatus?.alertSeverity;
      iocs[index].alerts = iocStatus?.alerts;
      iocs[index].active = iocStatus?.active ?? iocs[index].active;
      iocs[index].description = iocDetails?.description;
      return [...iocs];
    });
  }, [index, setIocs, tagOrCommitId, iocStatus, iocDetails]);

  return null;
}
