import React from "react";
import { styled } from "@mui/material/styles";
import {
  Button,
  TextField,
  Dialog,
  DialogActions,
  DialogContent,
  DialogTitle,
  DialogContentText
} from "@mui/material";
import Alert from "@mui/material/Alert";

const PREFIX = "IOCUndeployDialog";

const classes = {
  textField: `${PREFIX}-textField`
};

const StyledDialog = styled(Dialog)(({ theme }) => ({
  [`& .${classes.textField}`]: {
    marginBottom: theme.spacing(1)
  }
}));

export function IOCUndeployDialog({
  open,
  setOpen,
  submitCallback,
  ioc,
  error
}) {
  const handleClose = () => {
    setOpen(false);
  };

  const onSubmit = (event) => {
    event.preventDefault();
    const { comment: commentText } = event.currentTarget.elements;
    const comment = commentText.value;

    submitCallback({
      comment: comment
    });
  };

  return (
    <StyledDialog
      open={open}
      onClose={handleClose}
    >
      <form onSubmit={onSubmit}>
        <DialogTitle id="form-dialog-title">Undeploy</DialogTitle>
        <DialogContent>
          <DialogContentText>
            Do you really want to undeploy {ioc.namingName} from{" "}
            {ioc.activeDeployment.host.fqdn}?
          </DialogContentText>
          <TextField
            autoComplete="off"
            className={classes.textField}
            id="comment"
            label="Undeployment comment"
            variant="outlined"
            fullWidth
          />
          {error ? (
            <Alert
              severity="error"
              className={classes.alert}
            >
              {error}
            </Alert>
          ) : (
            <></>
          )}
        </DialogContent>
        <DialogActions>
          <Button
            onClick={handleClose}
            color="primary"
          >
            Cancel
          </Button>
          <Button
            color="primary"
            variant="contained"
            type="submit"
          >
            Undeploy
          </Button>
        </DialogActions>
      </form>
    </StyledDialog>
  );
}
