import React from "react";
import { Table } from "@ess-ics/ce-ui-common";
import { RecordStatusIcon } from "./RecordIcons";
import { Grid, Tooltip, Typography } from "@mui/material";
import { useRedirect } from "../../hooks/Redirect";
import { noWrapText } from "../common/Helper";

const recordsColumns = [
  {
    field: "bulb",
    headerName: "Status",
    flex: 0,
    headerAlign: "center",
    align: "center"
  },
  { field: "name", headerName: "Record", width: "15ch", sortable: false },
  {
    field: "description",
    headerName: "Description",
    width: "20ch",
    sortable: false
  },
  { field: "iocName", headerName: "IOC name", width: "10ch", sortable: false },
  { field: "hostName", headerName: "Host", width: "10ch", sortable: false }
];

const iocDetailsColumns = [
  {
    field: "bulb",
    headerName: "Status",
    flex: 0,
    headerAlign: "center",
    align: "center"
  },
  { field: "name", headerName: "Record", width: "15ch", sortable: false },
  { field: "iocVersion", headerName: "Version", width: "15ch", sortable: false }
];

function createRecordDescription(description) {
  return (
    <>
      {description ? (
        <Tooltip
          title={description}
          arrow
          enterDelay={400}
        >
          <Typography
            style={{
              overflow: "hidden",
              textOverflow: "ellipsis",
              whiteSpace: "nowrap"
            }}
          >
            {description}
          </Typography>
        </Tooltip>
      ) : (
        "---"
      )}
    </>
  );
}

export function createRecordsRow(record) {
  return {
    id: record.name,
    bulb: (
      <Grid
        container
        direction="column"
        justifyContent="center"
        alignItems="center"
      >
        <RecordStatusIcon record={record} />
      </Grid>
    ),
    name: noWrapText(record.name),
    description: createRecordDescription(record.description),
    iocName: record.iocName,
    hostName: record.hostName
  };
}

export function createIocDetailsRow(record) {
  return {
    id: record.name,
    bulb: (
      <Grid
        container
        direction="column"
        justifyContent="center"
        alignItems="center"
      >
        <RecordStatusIcon record={record} />
      </Grid>
    ),
    name: record.name,
    iocVersion: record.iocVersion
  };
}

export function RecordTable({
  records,
  rowType = "records",
  loading,
  pagination,
  onPage
}) {
  const tableTypeSpecifics = {
    records: [recordsColumns, createRecordsRow],
    iocDetails: [iocDetailsColumns, createIocDetailsRow]
  };

  const redirect = useRedirect();
  const [columns, createRow] = tableTypeSpecifics[rowType];
  const rows = (records?.recordList ?? []).map((record) => createRow(record));

  const itemLink = (name) => `/records/${encodeURIComponent(name)}`;
  const onRowClick = (record) => {
    redirect(itemLink(record?.id));
  };

  return (
    <Table
      columns={columns}
      rows={rows}
      onRowClick={onRowClick}
      pagination={pagination}
      onPage={onPage}
      loading={loading}
    />
  );
}
